@@ -1,10 +1,33 @@
 package App::PMUtils;
 
-our $DATE = '2014-12-29'; # DATE
-our $VERSION = '0.38'; # VERSION
+our $DATE = '2015-01-25'; # DATE
+our $VERSION = '0.39'; # VERSION
 
 use 5.010001;
 
+our $arg_module_multiple = {
+    schema => ['array*' => of=>'str*', min_len=>1],
+    req    => 1,
+    pos    => 0,
+    greedy => 1,
+    element_completion => sub {
+        require Complete::Module;
+        my %args = @_;
+        Complete::Module::complete_module(word=>$args{word});
+    },
+};
+
+our $arg_module_single = {
+    schema => 'str*',
+    req    => 1,
+    pos    => 0,
+    completion => sub {
+        require Complete::Module;
+        my %args = @_;
+        Complete::Module::complete_module(word=>$args{word});
+    },
+};
+
 1;
 # ABSTRACT: Command-line utilities related to Perl modules
 
@@ -20,7 +43,7 @@ App::PMUtils - Command-line utilities related to Perl modules
 
 =head1 VERSION
 
-This document describes version 0.38 of App::PMUtils (from Perl distribution App-PMUtils), released on 2015-12-29.
+This document describes version 0.39 of App::PMUtils (from Perl distribution App-PMUtils), released on 2015-01-25.
 
 =head1 SYNOPSIS
 
@@ -73,7 +96,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-PMUtil
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-App-PMUtils>.
+Source repository is at L<https://github.com/perlancar/perl-App-PMUtils>.
 
 =head1 BUGS
 
@@ -89,7 +112,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
